@@ -84,7 +84,8 @@
 #'   used (\code{"text"} by default) are understood and grouping respected.
 #'
 #' @section Computed variables:
-#' If output.type different from \code{"numeric"} the returned tibble contains columns:
+#' If output.type different from \code{"numeric"} the returned tibble contains
+#' columns:
 #' \describe{
 #'   \item{x,npcx}{x position}
 #'   \item{y,npcy}{y position}
@@ -121,7 +122,6 @@
 #' @family statistics for linear model fits
 #'
 #' @examples
-#' library(gginnards)
 #' # generate artificial data
 #' set.seed(4321)
 #' x <- 1:100
@@ -140,13 +140,6 @@
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(formula = formula, parse = TRUE)
 #'
-#' # as above but using geom_debug()
-#' ggplot(my.data, aes(x, y)) +
-#'   geom_point() +
-#'   geom_smooth(method = "lm", formula = formula) +
-#'   stat_poly_eq(formula = formula,
-#'                geom = "debug")
-#'
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
@@ -175,15 +168,18 @@
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
-#'   stat_poly_eq(aes(label =  paste(stat(eq.label), stat(adj.rr.label), sep = "~~~~")),
+#'   stat_poly_eq(aes(label =  paste(stat(eq.label),
+#'                                   stat(adj.rr.label), sep = "~~~~")),
 #'                formula = formula, parse = TRUE)
 #'
 #' # user specified label and digits
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
-#'   stat_poly_eq(aes(label =  paste(stat(eq.label), stat(adj.rr.label), sep = "~~~~")),
-#'                formula = formula, rr.digits = 3, coef.digits = 2, parse = TRUE)
+#'   stat_poly_eq(aes(label =  paste(stat(eq.label),
+#'                                   stat(adj.rr.label), sep = "~~~~")),
+#'                formula = formula, rr.digits = 3, coef.digits = 2,
+#'                parse = TRUE)
 #'
 #' # geom = "text"
 #' ggplot(my.data, aes(x, y)) +
@@ -203,13 +199,44 @@
 #'   stat_poly_eq(formula = formula,
 #'                output.type = "numeric",
 #'                parse = TRUE,
-#'                mapping = aes(label = sprintf(my.format,
-#'                                              stat(coef.ls)[[1]][[1, "Estimate"]],
-#'                                              stat(coef.ls)[[1]][[2, "Estimate"]],
-#'                                              stat(coef.ls)[[1]][[3, "Estimate"]],
-#'                                              stat(coef.ls)[[1]][[4, "Estimate"]])
-#'                                              )
-#'                              )
+#'                mapping =
+#'                 aes(label = sprintf(my.format,
+#'                                     stat(coef.ls)[[1]][[1, "Estimate"]],
+#'                                     stat(coef.ls)[[1]][[2, "Estimate"]],
+#'                                     stat(coef.ls)[[1]][[3, "Estimate"]],
+#'                                     stat(coef.ls)[[1]][[4, "Estimate"]])
+#'                                     )
+#'                    )
+#'
+#' # Examples using geom_debug() to show computed values
+#' #
+#' # This provides a quick way of finding out which variables are available for
+#' # use in mapping of aesthetics when using other geoms as in the examples
+#' # above.
+#'
+#' library(gginnards)
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   geom_smooth(method = "lm", formula = formula) +
+#'   stat_poly_eq(formula = formula, geom = "debug")
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   geom_smooth(method = "lm", formula = formula) +
+#'   stat_poly_eq(formula = formula, geom = "debug", output.type = "text")
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   geom_smooth(method = "lm", formula = formula) +
+#'   stat_poly_eq(formula = formula, geom = "debug", output.type = "numeric")
+#'
+#' # show the content of a list column
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   geom_smooth(method = "lm", formula = formula) +
+#'   stat_poly_eq(formula = formula, geom = "debug", output.type = "numeric",
+#'                summary.fun = function(x) {x[["coef.ls"]][[1]]})
 #'
 #' @export
 #'
@@ -218,7 +245,7 @@ stat_poly_eq <- function(mapping = NULL, data = NULL,
                          position = "identity",
                          ...,
                          formula = NULL,
-                         eq.with.lhs = "italic(y)~`=`~",
+                         eq.with.lhs = TRUE,
                          eq.x.rhs = NULL,
                          coef.digits = 3,
                          rr.digits = 2,
@@ -278,7 +305,7 @@ poly_eq_compute_group_fun <- function(data,
                                       scales,
                                       formula = NULL,
                                       weight = 1,
-                                      eq.with.lhs = "italic(y)~`=`~",
+                                      eq.with.lhs = TRUE,
                                       eq.x.rhs = NULL,
                                       coef.digits = 3,
                                       rr.digits = 2,
@@ -295,9 +322,16 @@ poly_eq_compute_group_fun <- function(data,
     return(tibble::new_tibble())
   }
 
+  output.type <- if (!length(output.type)) {
+    "expression"
+  } else {
+    tolower(output.type)
+  }
+  stopifnot(output.type %in%
+              c("expression", "text", "numeric", "latex", "tex", "tikz"))
+
   if (is.null(data$weight)) data$weight <- 1
 
-  output.type = tolower(output.type)
   if (is.null(eq.x.rhs)) {
     if (output.type == "expression") {
       eq.x.rhs <- "~italic(x)"
@@ -328,10 +362,12 @@ poly_eq_compute_group_fun <- function(data,
 
   if (output.type == "numeric") {
     z <- tibble::tibble(coef.ls = list(summary(mf)[["coefficients"]]),
+                        coefs = list(stats::coefficients(mf)),
                         r.squared = rr,
                         adj.r.squared = adj.rr,
                         AIC = AIC,
-                        BIC = BIC)
+                        BIC = BIC,
+                        rr.label = "") # needed for default 'label' mapping
   } else {
     coefs <- stats::coef(mf)
     formula.rhs.chr <- as.character(formula)[3]
@@ -341,13 +377,15 @@ poly_eq_compute_group_fun <- function(data,
 
     stopifnot(coef.digits > 0)
     if (coef.digits < 3) {
-      warning("Rounding coefficient estimates to fewer than three significant digits! Likely information loss!")
+      warning("'coef.digits < 3' Likely information loss!")
     }
     eq.char <- as.character(signif(polynom::as.polynomial(coefs), coef.digits))
     # as character drops 1
-    eq.char <- gsub("+ x", paste("+ 1.", stringr::str_dup("0", coef.digits - 1L),
-                                 "*x", sep = ""),
-                    eq.char, fixed = TRUE)
+    eq.char <-
+      gsub("+ x",
+           paste("+ 1.", stringr::str_dup("0", coef.digits - 1L), "*x",
+                 sep = ""),
+           eq.char, fixed = TRUE)
     eq.char <- gsub("e([+-]?[0-9]*)", "%*%10^{\\1}", eq.char)
     if (output.type %in% c("latex", "tex", "tikz")) {
       eq.char <- gsub("*", " ", eq.char, fixed = TRUE)
@@ -368,7 +406,7 @@ poly_eq_compute_group_fun <- function(data,
 
     stopifnot(rr.digits > 0)
     if (rr.digits < 2) {
-      warning("Rounding R-square to fewer than two significant digits! Likely information loss!")
+      warning("'rr.digits < 2' Likely information loss!")
     }
     rr.char <- format(rr, digits = rr.digits)
     adj.rr.char <- format(adj.rr, digits = rr.digits)
@@ -376,19 +414,19 @@ poly_eq_compute_group_fun <- function(data,
     BIC.char <- sprintf("%.4g", BIC)
     if (output.type == "expression") {
       z <- tibble::tibble(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
-                                        rr.label = paste("italic(R)^2", rr.char, sep = "~`=`~"),
-                                        adj.rr.label = paste("italic(R)[adj]^2",
-                                                             adj.rr.char, sep = "~`=`~"),
-                                        AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
-                                        BIC.label = paste("BIC", BIC.char, sep = "~`=`~"))
-    } else if (output.type %in% c("latex", "tex", "text")) {
-      z <-tibble::tibble(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
-                                        rr.label = paste("R^2", rr.char, sep = " = "),
-                                        adj.rr.label = paste("R_{adj}^2",
-                                                             adj.rr.char, sep = " = "),
-                                        AIC.label = paste("AIC", AIC.char, sep = " = "),
-                                        BIC.label = paste("BIC", BIC.char, sep = " = "))
-    } else if (!output.type %in% c("numeric")) {
+                          rr.label = paste("italic(R)^2", rr.char, sep = "~`=`~"),
+                          adj.rr.label = paste("italic(R)[adj]^2",
+                                               adj.rr.char, sep = "~`=`~"),
+                          AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
+                          BIC.label = paste("BIC", BIC.char, sep = "~`=`~"))
+    } else if (output.type %in% c("latex", "tex", "text", "tikz")) {
+      z <- tibble::tibble(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
+                         rr.label = paste("R^2", rr.char, sep = " = "),
+                         adj.rr.label = paste("R_{adj}^2",
+                                              adj.rr.char, sep = " = "),
+                         AIC.label = paste("AIC", AIC.char, sep = " = "),
+                         BIC.label = paste("BIC", BIC.char, sep = " = "))
+    } else {
       warning("Unknown 'output.type' argument: ", output.type)
     }
   }
@@ -400,7 +438,8 @@ poly_eq_compute_group_fun <- function(data,
     margin.npc <- 0
   }
   if (is.character(label.x)) {
-    label.x <- compute_npcx(x = label.x, group = group.idx, h.step = hstep, margin.npc = margin.npc)
+    label.x <- compute_npcx(x = label.x, group = group.idx, h.step = hstep,
+                            margin.npc = margin.npc)
     if (!npc.used) {
       x.expanse <- abs(diff(range(data$x)))
       x.min <- min(data$x)
@@ -408,7 +447,8 @@ poly_eq_compute_group_fun <- function(data,
     }
   }
   if (is.character(label.y)) {
-    label.y <- compute_npcy(y = label.y, group = group.idx, v.step = vstep, margin.npc = margin.npc)
+    label.y <- compute_npcy(y = label.y, group = group.idx, v.step = vstep,
+                            margin.npc = margin.npc)
     if (!npc.used) {
       y.expanse <- abs(diff(range(data$y)))
       y.min <- min(data$y)
